@@ -7,6 +7,13 @@ PROJECT_ID = "emart-datafabric"
 TEMP_DATASET = "temp_1d"
 CREDENTIALS_SECRET_MOUNT_POINT = "datafabric"
 CREDENTIALS_SECRET_PATH = "gcp/emart-datafabric/datafabric"
+PRINT_QUERY_JOB_RESULTS = False
+
+
+def print_query_job_results(print_query=False):
+    global PRINT_QUERY_JOB_RESULTS
+
+    PRINT_QUERY_JOB_RESULTS = print_query
 
 
 def get_credentials():
@@ -75,12 +82,16 @@ def _print_query_job_results(query_job):
     try:
         t = query_job.destination
         dest_str = f"{t.project}.{t.dataset_id}.{t.table_id}" if t else "no destination"
+
+        if PRINT_QUERY_JOB_RESULTS:
+            print(f"query: {query_job.query}\n")
+
         print(
-            f"query: {query_job.query}\n"
             f"destination: {dest_str}\n"
             f"total_rows: {query_job.result().total_rows}\n"
             f"slot_secs: {query_job.slot_millis / 1000}\n"
         )
+
     except Exception as e:
         print("Warning: exception on print statistics")
         print(e)
@@ -182,13 +193,13 @@ def _bq_query_to_existing_table(sql, destination, project=PROJECT_ID):
     return job.destination
 
 
-def _bq_table_to_pandas(table, project=PROJECT_ID):
+def _bq_table_to_pandas(table, project=PROJECT_ID, progress_bar_type="tqdm"):
     credentials = get_credentials()
     bq = get_bigquery_client(credentials=credentials, project=project)
     bqstorage_client = get_bigquery_storage_client(credentials=credentials)
     row_iterator = bq.list_rows(table)
     df = row_iterator.to_dataframe(
-        bqstorage_client=bqstorage_client, progress_bar_type="tqdm"
+        bqstorage_client=bqstorage_client, progress_bar_type=progress_bar_type
     )
     bq.close()
 
@@ -309,12 +320,15 @@ def _get_partition_filter(dataset, table_name, partition, project=PROJECT_ID):
     return ""
 
 
-def bq_to_pandas(sql, large=False):
+def bq_to_pandas(sql, large=False, verbose=True):
     destination = None
     if large:
         destination = get_temp_table()
     destination = _bq_query_to_new_table(sql, destination)
-    return _bq_table_to_pandas(destination)
+    progress_bar_type = None
+    if verbose:
+        progress_bar_type = "tqdm"
+    return _bq_table_to_pandas(destination, progress_bar_type=progress_bar_type)
 
 
 def _bq_table_to_df(
